---
title: Guides
description: Anaplan API & SDK Guides
hide:
  - toc
---

# Guides

The Anaplan API provides various [APIs](https://help.anaplan.com/anaplan-api-844c6d40-a21c-423d-8435-ebaaa0372b76) to interact
with the Anaplan platform. This SDK supports all of them and their respective domains and use cases. Refer to the
respective Guides to get started with each API.

<div class="grid cards" markdown>


- [__Bulk API__](bulk.md) for large and efficient data ingress & egress
- [__Transactional API__](transactional.md) for fine-grained manipulations of your models
- [__CloudWorks API__](cloud_works.md) for orchestrating and automating your Anaplan processes
- [__ALM API__](alm.md) for managing your Anaplan assets and their lifecycle
- [__Audit API__](audit.md) for tracking changes and maintaining compliance
- [__Auth APIs__](authentication.md) are used internally by the SDK to automatically manage authentication.

</div>
